# vktoken
Simple tool for getting VK access token

## Installation
`pip install --user vktoken`

## Usage
`vktoken [--help] [--version] [--app] login [password]`

## Examples
* `vktoken +79652331167`  
* `vktoken --app iphone +79523311167 mypassword` 

## Features
* You can choose VK app from the list: `android`, `iphone`, `ipad` and `windows-phone`.
